@@ -40,6 +40,21 @@ describe("path", {
     # This could be a UNC path, so we keep the doubled path.
     expect_equal(path("//", "foo"), "//foo")
   })
+
+  it("errors on paths which are too long", {
+    expect_error(path(paste(rep("a", 100000), collapse = "")), "less than PATH_MAX")
+
+    expect_error(do.call(path, as.list(rep("a", 100000))), "less than PATH_MAX")
+  })
+
+  it("follows recycling rules", {
+    expect_equal(path("foo", character()), character())
+    expect_equal(path("foo", "bar"), "foo/bar")
+    expect_equal(path("foo", c("bar", "baz")), c("foo/bar", "foo/baz"))
+    expect_equal(path(c("foo", "qux"), c("bar", "baz")), c("foo/bar", "qux/baz"))
+
+    expect_error(path(c("foo", "qux", "foo2"), c("bar", "baz")), "Arguments must have consistent lengths", class = "invalid_argument")
+  })
 })
 
 describe("path_wd", {
@@ -59,16 +74,6 @@ describe("path_real", {
     })
   })
 
-  it("returns the real path for symbolic links even if the full path doesn't exist", {
-    with_dir_tree(list("foo/bar/baz" = "test"), {
-      link_create(path_real("foo"), "foo2")
-      expect_equal(path_real("foo/qux"), path_real("foo/qux"))
-
-      link_create(path_real("foo/bar"), "bar2")
-      expect_equal(path_real("bar2/qux"), path_real("bar2/qux"))
-    })
-  })
-
   it ("works with indirect symlinks", {
     skip_on_os("windows")
 
@@ -92,7 +97,9 @@ describe("path_real", {
       wd <- path_wd()
       link_create("y", "k")
       withr::with_dir("k", {
+        file_create("a")
         expect_equal(path_real("a"), path(wd, "/y/a"))
+        unlink("a")
       })
     })
   })
@@ -286,6 +293,17 @@ describe("path_ext_set", {
     expect_equal(path_ext_set("foo", "bar"), "foo.bar")
     expect_equal(path_ext_set("foo", ".bar"), "foo.bar")
   })
+  it ("works with multiple paths (#205)", {
+    multiple_paths <- c("a", "b")
+    expect_equal(path_ext_set(multiple_paths, "csv"), c("a.csv", "b.csv"))
+  })
+  it ("works with multiple extensions (#250)", {
+    multiple_paths <- c("a", "b")
+    multiple_exts <- c("csv", "tsv")
+    expect_equal(path_ext_set(multiple_paths, multiple_exts), c("a.csv", "b.tsv"))
+
+    expect_error(path_ext_set(multiple_paths, c(multiple_exts, "xls")), class = "fs_error", "consistent lengths")
+  })
   it ("works with non-ASCII inputs", {
     skip_if_not_utf8()
 
@@ -398,13 +416,22 @@ describe("path_common", {
 })
 
 describe("path_has_parent", {
-  expect_false(path_has_parent("foo", "bar"))
-  expect_false(path_has_parent("foo", "foo/bar"))
+  it("works on single paths", {
+    expect_false(path_has_parent("foo", "bar"))
+    expect_false(path_has_parent("foo", "foo/bar"))
 
-  expect_false(path_has_parent("/usr/var2/log", "/usr/var"))
+    expect_false(path_has_parent("/usr/var2/log", "/usr/var"))
 
-  expect_true(path_has_parent("foo/bar", "foo"))
-  expect_true(path_has_parent("path/myfiles/myfile", "path/to/files/../../myfiles"))
+    expect_true(path_has_parent("foo/bar", "foo"))
+    expect_true(path_has_parent("path/myfiles/myfile", "path/to/files/../../myfiles"))
+  })
+  it("works with multiple paths", {
+    expect_equal(path_has_parent(c("/a/b/c", "x/y"), "/a/b"), c(TRUE, FALSE))
+
+    expect_equal(path_has_parent("/a/b/c", c("/a/b", "/x/y")), c(TRUE, FALSE))
+
+    expect_error(path_has_parent(c("/a/b/c", "x/y"), c("/a/b", "x/y", "foo/bar")), "consistent lengths", class = "invalid_argument")
+  })
 })
 
 # derived from https://github.com/python/cpython/blob/6f0eb93183519024cb360162bdd81b9faec97ba6/Lib/test/test_posixpath.py#L483
@@ -449,6 +476,8 @@ describe("path_rel", {
   })
 
   it("can be reversed by path_abs", {
+    skip_on_os("windows")
+
     f <- file_temp()
     expect_equal(path_abs(path_rel(f)), f)
 
